<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
https://pypi.org/project/django-readme-generator/
-->

[![](https://img.shields.io/badge/OS-MacOS-blue.svg?longCache=True)]()
[![](https://img.shields.io/pypi/pyversions/mac-task.svg?longCache=True)](https://pypi.org/project/mac-task/)

#### Installation
```bash
$ [sudo] pip install mac-task
```

#### Benefits
+   **no manual edit**. only classes and scripts!
+   **dynamic tasks state**
+   **macOS Applications from python classes**
+   **standalone django models usage**

#### How it works
mac-task based on [task.py](https://pypi.org/project/task/) and [mac-app-generator.py](https://pypi.org/project/mac-app-generator/):

```bash
site-packages/django_settings.py    # export DJANGO_SETTINGS_MODULE="django_settings"
site-packages/task_<name>.py        # module with AppTask subclass(es)
~/Applications/.tasks/<name>.app    # generated app

~/Logs/Applications/<name>/err.log
~/Logs/Applications/<name>/out.log

<alias>  # make app alias if task `todo` is True. for example, add app alias to Dock
```
you can customize app path, name, icon, logs, etc. more info at [mac-app-generator.py](https://pypi.org/project/mac-app-generator/)

#### Classes
class|`__doc__`
-|-
`mac_task.classes.AppTask` |MacOS app task class. inherited from `task.classes.Task` and `mac_app_generator.App`

#### Functions
function|`__doc__`
-|-
`mac_task.classes.getclasses()` |return a list of AppTask subclasses

#### Executable modules
usage|`__doc__`
-|-
`python -m mac_task.appify` |create applications from `AppTask` subclasses

#### Examples
```python
from mac_task.classes import AppTask
from task.models import Task

class Stand_up(AppTask):
    """Stand up and move around every 30 minutes"""

    def todo(self):
        return not self.completed_at or self.completed_at.elapsed.minutes >= 30

    def run(self):
        slideshow = mac_slideshow.restart()
        while self.sleep(0.1) and slideshow.running:
            if self.elapsed > 60:
                self.complete()
                self.say("warm-up is complete.[[slnc 1000]] you can back to work")
                break
        slideshow.stop()

if __name__ == "__main__":  # debug
    print(Task.objects.get(class_name=Stand_up.__name__))
```

#### What's Next?
+   create your custom `AppTask` subclass, e.g. - `site-packages/my_tasks.py`
```python
import task.setup
from mac_task.classes import AppTask

class MyApp(AppTask):
    ...
```

+   create categories, e.g.: `Now`, `Today`, ... and classes
```python
from task.models import Category

class Now(MyApp):
    @property
    def category(self):
        return Category.objects.get_or_create(**kwargs)[0]
```


+   create [LaunchAgents](https://pypi.org/project/mac-app-generator/) for reminders, [Dock](https://pypi.org/project/mac-dock/) [aliases](https://pypi.org/project/mkalias/), etc

+   add `remind()` method to your classes

+   add more interaction with macOS ([tts](https://pypi.org/project/mac-say/), [notification](https://pypi.org/project/growlnotify/), [slideshow](https://pypi.org/project/mac-slideshow/), [display on/off](https://pypi.org/project/mac-display/), etc) and enjoy!

#### Related projects
+   [launchd-generator - launchd.plist generator](https://pypi.org/project/mac-app-generator/)
+   [mac-app-generator.py - macOS app generator](https://pypi.org/project/mac-app-generator/)
+   [mac-display.py - macOS display sleep/wake](https://pypi.org/project/mac-display/)
+   [mac-dock.py - macOS Dock python interface](https://pypi.org/project/mac-dock/)
+   [mac-say.py - macOS tts. `say` python interface](https://pypi.org/project/mac-say/)
+   [mac-slideshow.py - macOS slideshow python interface](https://pypi.org/project/mac-say/)
+   [mkalias.py - macOS aliases](https://pypi.org/project/mkalias/)
+   [task.py - task management](https://pypi.org/project/task/)

<p align="center">
    <a href="https://pypi.org/project/django-readme-generator/">django-readme-generator</a>
</p>